﻿using System;
using System.Windows.Forms;

namespace SSRSSEditor
{
    public partial class EditItemForm : Form
    {
        RssItem _item;
        bool _newItem;
        bool ignoreChanges;
        bool dirty = false;

        public EditItemForm(ref RssItem item, bool newItem)
        {
            _item = item;
            _newItem = newItem;
            InitializeComponent();
        }

        private void EditItemForm_Load(object sender, EventArgs e)
        {
            chkUpdatePubdate.Checked = true;
            if (_newItem)
            {
                this.Text = "Create new Item";
                chkUpdatePubdate.Hide();    // Always updated on new items
            }
            else
            {
                this.Text = "Editing Item";

                ignoreChanges = true;
                txtTitle.Text = _item.title;
                txtDesc.Text = _item.description;
                txtLink.Text = _item.link;
                ignoreChanges = false;
            }
            UpdateSaveButton();
        }

        private void UpdateSaveButton()
        {
            btnSave.Enabled = dirty;
        }

        private void txtTitle_TextChanged(object sender, EventArgs e)
        {
            if (!ignoreChanges)
            {
                dirty = true;
                UpdateSaveButton();
            }
        }

        private void txtLink_TextChanged(object sender, EventArgs e)
        {
            UrlUtils.ValidateUrl(txtLink, false);
            if (!ignoreChanges)
            {
                dirty = true;
                UpdateSaveButton();
            }
        }

        private void btnOpenLink_Click(object sender, EventArgs e)
        {
            if (!txtLink.Text.IsNullOrEmpty() && UrlUtils.ValidateUrl(txtLink, true))
                UrlUtils.OpenInBrowser(txtLink.Text);
        }

        private void txtDesc_TextChanged(object sender, EventArgs e)
        {
            UrlUtils.ValidateUrl(txtLink, false);
            if (!ignoreChanges)
            {
                dirty = true;
                UpdateSaveButton();
            }
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            if(!CheckRequiredField(txtTitle, "Title"))
                return;
            if(!CheckRequiredField(txtDesc, "Description"))
                return;
            if(!CheckRequiredField(txtLink, "Link"))
                return;

            if (!UrlUtils.ValidateUrl(txtLink, true))
                return;

            _item.title = txtTitle.Text;
            _item.link = txtLink.Text;
            _item.description = txtDesc.Text;

            if (chkUpdatePubdate.Checked)
                _item.UpdatePubDate();

            this.DialogResult = DialogResult.OK;
            Close();
        }

        private bool CheckRequiredField(TextBox box, string name)
        {
            if (!box.Text.IsNullOrEmpty())
                return true;
            Program.MsgBox("A "+name+" is required.", MessageBoxButtons.OK);
            box.Focus();
            return false;
        }
    }
}
